@@ -134,7 +134,7 @@ class PretranslateTestCase(unittest.TestCase):
         self.assertEqual(slugify_reverse('slug'), 'guls')
 
     def test_wrong_argument_type(self):
-        self.assertRaises(ValueError, lambda: Slugify(pretranslate={1, 2}))
+        self.assertRaises(ValueError, lambda: Slugify(pretranslate=set([1, 2])))
 
 
 class SanitizeTestCase(unittest.TestCase):
@@ -205,6 +205,35 @@ class TruncateTestCase(unittest.TestCase):
         self.assertEqual(slugify('one two three four', max_length=14, separator='...'), 'one...two')
 
 
+class FoldAbbreviationTestCase(unittest.TestCase):
+    def test_not_fold_abbr(self):
+        slugify = Slugify(fold_abbrs=False)
+        self.assertEqual('Back-in-U-S-S-R', slugify('Back in U.S.S.R.'))
+
+    def test_fold_abbr(self):
+        slugify = Slugify(fold_abbrs=True)
+        self.assertEqual('Back-in-USSR', slugify('Back in U.S.S.R.'))
+        self.assertEqual('Back-in-USSR', slugify('Back in U.S.S.R'))
+
+    def test_fold_abbr_1(self):
+        self.assertEqual('Back-in-USSR-Text', slugify('Back in U.S.S.R. () Text', fold_abbrs=True))
+
+    def test_fold_abbr_2(self):
+        slugify = Slugify(fold_abbrs=True)
+        self.assertEqual('Back-in-USSR-Text', slugify('Back in U.S.S.R. () Text'))
+
+    def test_fold_abbr_3(self):
+        slugify = Slugify(fold_abbrs=True)
+        self.assertEqual('Back-in-USSR-Text', slugify('Back in U.S.S.R. () Text'))
+
+    def test_fold_abbr_4(self):
+        slugify = Slugify(fold_abbrs=True)
+        self.assertEqual('mind-in-a-box', slugify('mind.in.a.box'))
+        self.assertEqual('mind-in-a-b-c-box', slugify('mind.in.a.b.c.box'))
+        self.assertEqual('a-b-c-box', slugify('.a.b.c.box'))
+        self.assertEqual('abcbox', slugify('a.b.c.box'))
+        self.assertEqual('abcb-ox', slugify('a.b.c.b ox'))
+
 class OtherTestCase(unittest.TestCase):
 
     def test_prevent_double_pretranslation(self):
@@ -234,6 +263,11 @@ class UniqueTestCase(unittest.TestCase):
         slugify = UniqueSlugify(uids=['This-is-my-test', 'This-is-another-test'])
         self.assertEqual(slugify('This % is a test ---'), 'This-is-a-test')
         self.assertEqual(slugify('This % is my test ---'), 'This-is-my-test-1')
+        self.assertTrue(isinstance(slugify.uids, set))
+
+        slugify = UniqueSlugify(uids=set(["let-me-not", "to-the-marriage", "of-true-minds"]))
+        self.assertEqual(slugify("of-true-minds"), "of-true-minds-1")
+        self.assertEqual(slugify("of-true-minds"), "of-true-minds-2")
 
     def test_init_other(self):
         slugify = UniqueSlugify(separator=u'_')
@@ -245,6 +279,17 @@ class UniqueTestCase(unittest.TestCase):
         self.assertEqual(slugify('This % is another test ---', separator='_'), 'This_is_another_test')
         self.assertEqual(slugify('- - -This -- is another ## test ---', separator='_'), 'This_is_another_test_1')
 
+    def test_is_unique_override(self):
+        def my_unique_check(text, uids):
+            return len(text) > 3 and text not in uids
+
+        slugify = UniqueSlugify(unique_check=my_unique_check)
+
+        self.assertEqual(slugify('te occidere possunt'), 'te-occidere-possunt')
+        self.assertEqual(slugify('te occidere possunt'), 'te-occidere-possunt-1')
+        self.assertEqual(slugify('boo'), 'boo-1')
+        self.assertEqual(slugify('boo'), 'boo-2')
+
 
 class DeprecationTestCase(unittest.TestCase):
 
@@ -256,7 +301,7 @@ class DeprecationTestCase(unittest.TestCase):
 
             slugify = get_slugify()
             self.assertEqual(slugify('This % is a test ---'), 'This-is-a-test')
-            self.assertIn("'slugify.get_slugify' is deprecated", str(warning[-1].message))
+            self.assertTrue("'slugify.get_slugify' is deprecated" in str(warning[-1].message))
 
 
 if __name__ == '__main__':
